import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:flutter_threatmetrix_module/flutter_threatmetrix_module.dart';

class WebviewContainer extends StatelessWidget {
  WebviewContainer({Key? key, required this.url}) : super(key: key);

  final String url;
  final GlobalKey webViewKey = GlobalKey();
  final _flutterThreatmetrixModulePlugin = FlutterThreatmetrixModule();

  InAppWebViewController? webViewController;
  InAppWebViewSettings settings =
      InAppWebViewSettings(javaScriptEnabled: true, geolocationEnabled: true);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Webview Example'),
      ),
      body: SizedBox(
        width: double.infinity,
        // the most important part of this example
        child: InAppWebView(
          key: webViewKey,
          // initialUrlRequest: URLRequest(url: WebUri('https://flutter.dev')),
          onWebViewCreated: (InAppWebViewController controller) async {
            await controller.loadUrl(urlRequest: URLRequest(url: WebUri(url)));
            controller.addJavaScriptHandler(
              handlerName: 'PayDala',
              callback: (args) {
                // print arguments coming from the JavaScript side!
                print('Received arguments from JavaScript: ');
                print(args);

                // return data to the JavaScript side!
              },
            );
            if (await WebViewFeature.isFeatureSupported(
                WebViewFeature.WEB_MESSAGE_LISTENER)) {
              print('inside web message listener');
              await controller.addWebMessageListener(WebMessageListener(
                jsObjectName: "PayDala",
                allowedOriginRules: {"*"},
                onPostMessage:
                    (message, sourceOrigin, isMainFrame, replyProxy) {
                  print("Received message from $sourceOrigin: $message");
                  if (message?.type == 'sessionCreated') {
                    getProfilingData("hfkdjsfhdksjfhsk");
                  }
                },
              ));
              getProfilingData("hfkdjsfhdksjfhsk");
            }
          },
          onLoadStart: (InAppWebViewController controller, Uri? url) {
            print('onLoadStart $url');
          },

          onLoadStop: (InAppWebViewController controller, Uri? url) async {
            print('onLoadStop $url');
            if (await WebViewFeature.isFeatureSupported(
                WebViewFeature.CREATE_WEB_MESSAGE_CHANNEL)) {
              // wait until the page is loaded, and then create the Web Message Channel
              var webMessageChannel =
                  await controller.createWebMessageChannel();
              var port1 = webMessageChannel!.port1;
              var port2 = webMessageChannel.port2;

              // set the web message callback for the port1
              await port1.setWebMessageCallback((message) async {
                print("Message coming from the JavaScript side: $message");
                // when it receives a message from the JavaScript side, respond back with another message.
                // await port1
                //     .postMessage(WebMessage(data: message!));
              });

              // transfer port2 to the webpage to initialize the communication
              await controller.postWebMessage(
                  message: WebMessage(data: "capturePort", ports: [port2]),
                  targetOrigin: WebUri("*"));
            }
          },
          onProgressChanged: (InAppWebViewController controller, int progress) {
            print('onProgressChanged $progress');
          },
          onGeolocationPermissionsShowPrompt:
              (InAppWebViewController controller, String origin) async {
            return GeolocationPermissionShowPromptResponse(
                origin: origin, allow: true, retain: true);
          },
          onConsoleMessage: (controller, consoleMessage) {
            print("console message: ${consoleMessage.message}");
          },
        ),
      ),
    );
  }

  Future<void> getProfilingData(String sessionId) async {
    String profileData = 'No Data';
    String? error;
    String orgId = '52whdrrv';
    String fpServer = 'h-sdk.online-metrix.net';

    try {
      final result = await FlutterThreatmetrixModule()
              .getProfilingData(sessionId, orgId, fpServer) ??
          'No Data';
      profileData = result;
    } catch (e) {
      error = e.toString();
    }
  }
}
